pub struct AccountStateResponse {
pub mc_seqno: u32,
pub gen_utime: u32,
pub state: Bytes,
}Fields
mc_seqno: u32gen_utime: u32state: BytesA BOC with a ShardAccount.
NOTE: BocRepr cannot be safely used here because
we must hold a state tracker handle to delay the GC,
and it is very inconvenient to pass it around here.
Implementations
Sourceimpl AccountStateResponse
impl AccountStateResponse
pub fn parse(&self) -> Result<ParsedAccountState, BocReprError>